# AgUnreal

A simple Python package to create AI-Enhanced games.

## Installation

```bash
pip install agunreal
```

## Usage

```python
from agunreal import Game, Scene, Player, Light, Skybox

game = Game("EpicBattle")

scene = Scene("ForestArena")
scene.add(Skybox("SkyNight"))

player = Player("Knight", model="knight.fbx", spawn=(0, 0, 1))
scene.add(player)

game.load_scene(scene)
game.run()

```
